# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/grpc/core.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63ore/grpc/core.proto\x12\x0c\x64\x61rsman.core\x1a\x1cgoogle/protobuf/struct.proto\"\xaf\x01\n\x0e\x41\x64\x64ItemRequest\x12\x17\n\x0fitem_identifier\x18\t \x01(\t\x12\x30\n\nextra_data\x18\n \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x12\x19\n\x11\x62\x61sket_identifier\x18\x0b \x01(\t\x12\x18\n\x0binstallment\x18\x0c \x01(\x08H\x01\x88\x01\x01\x42\r\n\x0b_extra_dataB\x0e\n\x0c_installment\"D\n\x1a\x42\x61sketApplyDiscountRequest\x12\x0e\n\x06\x62\x61sket\x18\x01 \x01(\t\x12\x16\n\x0e\x64iscount_token\x18\x02 \x01(\t\"D\n\x18\x42\x61sketAssignOwnerRequest\x12\x0e\n\x06\x62\x61sket\x18\x01 \x01(\t\x12\x18\n\x10owner_identifier\x18\x02 \x01(\t\"y\n\rBasketRequest\x12\x1d\n\x10owner_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11\x62\x61sket_identifier\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_owner_identifierB\x14\n\x12_basket_identifier\"u\n\x0e\x42\x61sketResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"2\n\x15\x42\x61sketRetrieveRequest\x12\x19\n\x11\x62\x61sket_identifier\x18\x01 \x01(\t\"\x86\x01\n\x0f\x45ndTradeRequest\x12\x16\n\x0egateway_status\x18\x01 \x01(\t\x12\x1a\n\x12payment_identifier\x18\x02 \x01(\t\x12\x30\n\nextra_data\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x42\r\n\x0b_extra_data\"@\n\x16InstallmentTermRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x12\n\nitem_price\x18\x02 \x01(\x05\"\x88\x01\n\x11RemoveItemRequest\x12\x17\n\x0fitem_identifier\x18\x07 \x01(\t\x12\x30\n\nextra_data\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x12\x19\n\x11\x62\x61sket_identifier\x18\t \x01(\tB\r\n\x0b_extra_data\"o\n\x08Response\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"#\n\x11StartTradeRequest\x12\x0e\n\x06\x62\x61sket\x18\x01 \x01(\t2\xdc\x03\n\x10\x42\x61sketController\x12\x41\n\x07\x41\x64\x64Item\x12\x1c.darsman.core.AddItemRequest\x1a\x16.darsman.core.Response\"\x00\x12S\n\rApplyDiscount\x12(.darsman.core.BasketApplyDiscountRequest\x1a\x16.darsman.core.Response\"\x00\x12O\n\x0b\x41ssignOwner\x12&.darsman.core.BasketAssignOwnerRequest\x1a\x16.darsman.core.Response\"\x00\x12\x45\n\x06\x43reate\x12\x1b.darsman.core.BasketRequest\x1a\x1c.darsman.core.BasketResponse\"\x00\x12G\n\nRemoveItem\x12\x1f.darsman.core.RemoveItemRequest\x1a\x16.darsman.core.Response\"\x00\x12O\n\x08Retrieve\x12#.darsman.core.BasketRetrieveRequest\x1a\x1c.darsman.core.BasketResponse\"\x00\x32g\n\x19InstallmentTermController\x12J\n\x08Retrieve\x12$.darsman.core.InstallmentTermRequest\x1a\x16.darsman.core.Response\"\x00\x32\x95\x01\n\x0fTradeController\x12>\n\x03\x45nd\x12\x1d.darsman.core.EndTradeRequest\x1a\x16.darsman.core.Response\"\x00\x12\x42\n\x05Start\x12\x1f.darsman.core.StartTradeRequest\x1a\x16.darsman.core.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.grpc.core_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDITEMREQUEST']._serialized_start=69
  _globals['_ADDITEMREQUEST']._serialized_end=244
  _globals['_BASKETAPPLYDISCOUNTREQUEST']._serialized_start=246
  _globals['_BASKETAPPLYDISCOUNTREQUEST']._serialized_end=314
  _globals['_BASKETASSIGNOWNERREQUEST']._serialized_start=316
  _globals['_BASKETASSIGNOWNERREQUEST']._serialized_end=384
  _globals['_BASKETREQUEST']._serialized_start=386
  _globals['_BASKETREQUEST']._serialized_end=507
  _globals['_BASKETRESPONSE']._serialized_start=509
  _globals['_BASKETRESPONSE']._serialized_end=626
  _globals['_BASKETRETRIEVEREQUEST']._serialized_start=628
  _globals['_BASKETRETRIEVEREQUEST']._serialized_end=678
  _globals['_ENDTRADEREQUEST']._serialized_start=681
  _globals['_ENDTRADEREQUEST']._serialized_end=815
  _globals['_INSTALLMENTTERMREQUEST']._serialized_start=817
  _globals['_INSTALLMENTTERMREQUEST']._serialized_end=881
  _globals['_REMOVEITEMREQUEST']._serialized_start=884
  _globals['_REMOVEITEMREQUEST']._serialized_end=1020
  _globals['_RESPONSE']._serialized_start=1022
  _globals['_RESPONSE']._serialized_end=1133
  _globals['_STARTTRADEREQUEST']._serialized_start=1135
  _globals['_STARTTRADEREQUEST']._serialized_end=1170
  _globals['_BASKETCONTROLLER']._serialized_start=1173
  _globals['_BASKETCONTROLLER']._serialized_end=1649
  _globals['_INSTALLMENTTERMCONTROLLER']._serialized_start=1651
  _globals['_INSTALLMENTTERMCONTROLLER']._serialized_end=1754
  _globals['_TRADECONTROLLER']._serialized_start=1757
  _globals['_TRADECONTROLLER']._serialized_end=1906
# @@protoc_insertion_point(module_scope)
